==> anywhereSSL_0.3.0.tar.gz: anywhereSSL/include/precheck.inc.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// ľܸƤӽФ줿exit
//*****************************************************************************/
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if ( ! function_exists('awsslPreCheck') ) {

	/**
	 * awsslPreCheck
	 * 
	 * @param void
	 * @return void
	 */
	function awsslPreCheck() {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );
		
		//*****************************************************************************/
		// ⥸塼꤬Ǥʤϥå
		//*****************************************************************************/
		if ( !empty($awssl_config) ) {
		
			//*************************************************************************/
			// ⥸塼ܾ
			//*************************************************************************/
			include( $mod_path .'/class/anywheressl.class.php' );
			$Anywheressl = new Anywheressl( $awssl_config );
			
			//*************************************************************************/
			// ɺѤߤåԤ
			//*************************************************************************/
			$awssl_loaded = !empty( $_SESSION['AWSSL_LOADED'] ) ? true : false;
			
			//*************************************************************************/
			// åΥåȤԤ
			//*************************************************************************/
			$Anywheressl->setSecureCookie();
			
			//*************************************************************************/
			// ɺѤߤǤʤ硢̤
			//*************************************************************************/
			if ( ! $awssl_loaded ) {
				$current_script = basename($_SERVER['SCRIPT_FILENAME']);
				$query_string = !empty( $_SERVER['QUERY_STRING'] ) ? '?' .$_SERVER['QUERY_STRING'] : '';
				header( "Location: " .$current_script .$query_string );
			}
			
			//*************************************************************************/
			// SSL/SSLڤؤȤƥåIDղäƤ
			//*************************************************************************/
			$session_name = urldecode( $awssl_config['session_name']['conf_value'] );
			if ( ! empty($_GET[$session_name]) ) {
				// MyTextSanitizer󥹥󥹤
				$myts =& MyTextSanitizer::getInstance();
				$session_id = $myts->stripSlashesGPC( $_GET[$session_name] );
				if ( preg_match('/[^a-zA-Z0-9*]{32}$/i', $session_id, $matches) ) {
					redirect_header( XOOPS_URL, 2, AWSSL_ERR_ILLEGITIMATE_OP );
					exit;
				}
				// ˳Ǽå
				$awssl_session = $Anywheressl->getAwsslSession( $session_id );
				if ( !empty($awssl_session) ) {
					$Anywheressl->delAwsslSession( $session_id );
				}
				$_SESSION = $awssl_session;
				// $_GETǥåIDϤƤ뤿ᡢ٥åIDѹ
				$Anywheressl->awsslSessionRegenerateId( $regenerate = true );
				// åIDURL
				$current_script = basename($_SERVER['SCRIPT_FILENAME']);
				$query_string = str_replace( $session_name .'=' .$session_id , '', $_SERVER['QUERY_STRING'] );
				$query_string = !empty( $query_string ) ? substr( $query_string, 0, strlen($query_string) - 1 ) : '';
				$query_string = !empty( $query_string ) ? '?' .$query_string : '';
				header( "Location: " .$current_script .$query_string );
			}
		
			//*************************************************************************/
			// 奢°ղáʥåIDڤؤ"Ϥ"ξڤؤ
			//*************************************************************************/
			$session_regenerate_id = ( $awssl_config['session_regenerate_id']['conf_value'] === 'yes' ) ? true : false;
			$Anywheressl->awsslSessionRegenerateId( $regenerate = $session_regenerate_id );

			//*************************************************************************/
			// SSL-Loginοƥɥν񤭴
			//*************************************************************************/
			$current_url = $Anywheressl->getCurrentUrl();
			if ( $current_url === XOOPS_URL .'/misc.php?action=showpopups&type=ssllogin' ) {
				include_once( $mod_path .'/include/sslloginbuf.inc.php' );
			}
		}
	}
}

awsslPreCheck();

?>

==> anywhereSSL_0.3.1.tar.gz: anywhereSSL/include/precheck.inc.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// ľܸƤӽФ줿exit
//*****************************************************************************/
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if ( ! function_exists('awsslPreCheck') ) {

	/**
	 * awsslPreCheck
	 * 
	 * @param void
	 * @return void
	 */
	function awsslPreCheck() {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );
		
		//*****************************************************************************/
		// ⥸塼꤬Ǥʤϥå
		//*****************************************************************************/
		if ( ! empty($awssl_config) ) {
		
			//*************************************************************************/
			// ⥸塼ܾ
			//*************************************************************************/
			include( $mod_path .'/class/anywheressl.class.php' );
			$Anywheressl = new Anywheressl( $awssl_config );
			
			//*************************************************************************/
			// ɺѤߤåԤ
			//*************************************************************************/
			$awssl_loaded = !empty( $_SESSION['AWSSL_LOADED'] ) ? true : false;
			
			//*************************************************************************/
			// åΥåȤԤ
			//*************************************************************************/
			$Anywheressl->setSecureCookie();
			
			//*************************************************************************/
			// ɺѤߤǤʤ硢̤
			//*************************************************************************/
			if ( ! $awssl_loaded ) {
				$current_script = basename($_SERVER['SCRIPT_FILENAME']);
				$query_string = !empty( $_SERVER['QUERY_STRING'] ) ? '?' .$_SERVER['QUERY_STRING'] : '';
				header( "Location: " .$current_script .$query_string );
			}
			
			//*************************************************************************/
			// SSL/SSLڤؤȤƥåIDղäƤ
			//*************************************************************************/
			$session_name = urldecode( $awssl_config['session_name']['conf_value'] );
			if ( ! empty($_GET[$session_name]) ) {
				// MyTextSanitizer󥹥󥹤
				$myts =& MyTextSanitizer::getInstance();
				$session_id = $myts->stripSlashesGPC( $_GET[$session_name] );
				if ( preg_match('/[^a-zA-Z0-9*]{32}$/i', $session_id, $matches) ) {
					redirect_header( XOOPS_URL, 2, AWSSL_ERR_ILLEGITIMATE_OP );
					exit;
				}
				// ˳Ǽå
				$Anywheressl->getAwsslSession( $session_id );
				// åDB
				$Anywheressl->delAwsslSession( $session_id );
				// $_GETǥåIDϤƤ뤿ᡢ٥åIDѹ
				$Anywheressl->awsslSessionRegenerateId( $regenerate = true );
				// åIDURL
				$current_script = basename($_SERVER['SCRIPT_FILENAME']);
				$query_string = str_replace( $session_name .'=' .$session_id , '', $_SERVER['QUERY_STRING'] );
				$query_string = !empty( $query_string ) ? substr( $query_string, 0, strlen($query_string) - 1 ) : '';
				$query_string = !empty( $query_string ) ? '?' .$query_string : '';
				header( "Location: " .$current_script .$query_string );
			}
		
			//*************************************************************************/
			// 奢°ղáʥåIDڤؤ"Ϥ"ξڤؤ
			//*************************************************************************/
			$session_regenerate_id = ( $awssl_config['session_regenerate_id']['conf_value'] === 'yes' ) ? true : false;
			$Anywheressl->awsslSessionRegenerateId( $regenerate = $session_regenerate_id );

			//*************************************************************************/
			// SSL-Loginοƥɥν񤭴
			//*************************************************************************/
			$current_url = $Anywheressl->getCurrentUrl();
			if ( $current_url === XOOPS_URL .'/misc.php?action=showpopups&type=ssllogin' ) {
				include_once( $mod_path .'/include/sslloginbuf.inc.php' );
			}
		} else {
			//*************************************************************************/
			// ܶػߥե饰
			//*************************************************************************/
			if ( ! defined( 'AWSSL_CANNOT_DESTINE' ) ) {
				define( 'AWSSL_CANNOT_DESTINE', 1 );
			}
		}
	}

	awsslPreCheck();

}


?>
